@@ -19,7 +19,7 @@
  * You should have received a copy of the GNU General Public License
  * along with "prooftree". If not, see <http://www.gnu.org/licenses/>.
  * 
- * $Id: input.ml,v 1.27 2012-01-02 15:50:50 tews Exp $
+ * $Id: input.ml,v 1.28 2012-01-04 15:12:38 tews Exp $
  *)
 
 
@@ -156,18 +156,29 @@
     {- Full name of the proof}
     }
     }
-    {- {v proof-complete state %d {cheated|not-cheated} \
-    proof-name-bytes %d command-bytes %d\n\
+    {- {v proof-finished state %d {cheated|not-cheated} \
+    proof-name-bytes %d command-bytes %d existential-bytes %d\n\
     <data-proof-name>\n\
-    <data-command>\n v}
+    <data-command>\n\
+    <data-existentials>\n v}
     
-    [proof-complete] tells [prooftree] the last proof command that 
-    finished the current proof. The cheated flag tells [prooftree]
+    [proof-finished] tells [prooftree] the last proof command that 
+    closed the last subgoal. The cheated flag tells [prooftree]
     whether the new proof state was obtained by a cheating command 
     such as [admit] or [sorry]. The data sections are :
     {ol
     {- Full name of the proof}
     {- The last proof command}
+    {- Prover specific information about existential variables.}
+    }
+    }
+    {- {v proof-complete state %d proof-name-bytes %d\n\
+    <data-proof-name>\n v}
+
+    [proof-complete] tells Prooftree that the current proof has been
+    completed and will further not be updated. The only data section is:
+    {ol
+    { - Full name of the proof}
     }
     }
     {- {v undo-to state %d\n v}
@@ -192,7 +203,7 @@
 (** Version number of the communication protocol described and
     implemented by this module.
 *)
-let protocol_version = 1
+let protocol_version = 2
 
 
 
@@ -461,8 +472,7 @@ let parse_current_goals_finish state current_sequent_id cheated_string
   let additional_ids_string = chop_final_newlines additional_ids_string in
   let additional_ids = string_split ' ' additional_ids_string in
   let existentials_string = chop_final_newlines existentials_string in
-  let (ex_uninst, ex_inst) = 
-    !parse_existential_info existentials_string in
+  let (ex_uninst, ex_inst) = !parse_existential_info existentials_string in
   Proof_tree.process_current_goals state proof_name proof_command cheated_flag
     current_sequent_id current_sequent_text additional_ids ex_uninst ex_inst
     
@@ -578,60 +588,93 @@ let parse_switch_goal com_buf =
 
 
 (******************************************************************************
- * proof-complete state %d {cheated|not-cheated} \
- * proof-name-bytes %d command-bytes %d\n\
+ * proof-finished state %d {cheated|not-cheated} \
+ * proof-name-bytes %d command-bytes %d existential-bytes %d\n\
  * <data-proof-name>\n\
- * <data-command>\n
+ * <data-command>\n\
+ * <data-existentials>\n
 *)
 
-(** {3 Proof-complete command parser} *)
+(** {3 Proof-finished command parser} *)
 
 
-(** Finish parsing of the [proof-complete] command and process it
-    with {!Proof_tree.process_proof_complete}. The arguments are
+(** Finish parsing of the [proof-finished] command and process it
+    with {!Proof_tree.process_proof_finished}. The arguments are
 
     @param state state number
     @param cheated_string either "cheated" or "not-cheated"
     @param proof_name full proof name (as raw data section string)
     @param proof_command last proof command (as raw data section string)
+    @param existentials_string prover specific data about existentials
 *)
-let parse_proof_complete_finish state cheated_string proof_name proof_command =
+let parse_proof_finished_finish 
+    state cheated_string proof_name proof_command existentials_string =
   let cheated_flag = match cheated_string with
     | "not-cheated" -> false
     | "cheated" -> true
     | _ -> 
       raise(Protocol_error
-	      ("Parse error in proof-complete command. " ^
+	      ("Parse error in proof-finished command. " ^
 		  "Expected \"cheated\" or \"not-cheated\" as 4th word.",
 	       None))
   in
   let proof_name = chop_final_newlines proof_name in
   let proof_command = chop_final_newlines proof_command in
-  Proof_tree.process_proof_complete state proof_name proof_command cheated_flag
+  let existentials_string = chop_final_newlines existentials_string in
+  let (ex_uninst, ex_inst) = !parse_existential_info existentials_string in
+  Proof_tree.process_proof_finished 
+    state proof_name proof_command cheated_flag ex_uninst ex_inst
 
 
-(** Parse and process a [proof-complete] command. Extracts the
+(** Parse and process a [proof-finished] command. Extracts the
     necessary information from the first command line in the [Scanf]
     parsing buffer argument, reads the data section and finally calls
-    {!Input.parse_proof_complete_finish}.
+    {!Input.parse_proof_finished_finish}.
 *)
-let parse_proof_complete com_buf =
+let parse_proof_finished com_buf =
   check_if_configured ();
-  Scanf.bscanf com_buf " state %d %s proof-name-bytes %d command-bytes %d"
-    (fun state cheated_string proof_name_bytes command_bytes ->
+  Scanf.bscanf com_buf
+    " state %d %s proof-name-bytes %d command-bytes %d existential-bytes %d"
+    (fun state cheated_string proof_name_bytes 
+                                    command_bytes existential_bytes ->
       get_string proof_name_bytes 
 	(fun proof_name ->
 	  get_string command_bytes
 	    (fun proof_command ->
-	      parse_proof_complete_finish 
-		state cheated_string proof_name proof_command)))
+	      get_string existential_bytes
+		(fun existentials_string ->
+		  parse_proof_finished_finish 
+		    state cheated_string proof_name 
+		    proof_command existentials_string))))
 
 
 
 (******************************************************************************
- * undo-to state %d\n
+ * proof-complete state %d proof-name-bytes %d\n\
+ * <data-proof-name>\n
  *)
 
+(** {3 Proof-complete command parser} *)
+
+
+(** Parse and process a [proof-complete] command. Extracts information
+    from the command and process it with
+    {!Proof_tree.process_proof_complete}.
+ *)
+let parse_proof_complete com_buf =
+  check_if_configured ();
+  Scanf.bscanf com_buf " state %d proof-name-bytes %d"
+    (fun state proof_name_bytes ->
+      get_string proof_name_bytes 
+	(fun proof_name ->
+	  let proof_name = chop_final_newlines proof_name in
+	  Proof_tree.process_proof_complete state proof_name))
+
+
+(******************************************************************************
+									       * undo-to state %d\n
+*)
+
 (** {3 Undo-to command parser} *)
 
 
@@ -698,6 +741,7 @@ let parse_command command =
       | "current-goals" -> parse_current_goals com_buf
       | "update-sequent" -> parse_update_sequent com_buf
       | "switch-goal" -> parse_switch_goal com_buf
+      | "proof-finished" -> parse_proof_finished com_buf
       | "proof-complete" -> parse_proof_complete com_buf
       | "undo-to" -> do_undo com_buf
       | "quit-proof" -> parse_quit_proof com_buf
